@@ -35,8 +35,8 @@
 
 #include "catalogitem.h"
 
-#include <kdemacros.h>
-#include <QDebug>
+#include "lokalize_debug.h"
+
 #include <QMutexLocker>
 
 using namespace GettextCatalog;
@@ -50,7 +50,7 @@ QString CatalogItem::msgctxt(const bool noNewlines) const
 
 const QString& CatalogItem::msgstr(const int form) const
 {
-    if (KDE_ISLIKELY (form<d._msgstrPlural.size()))
+    if (Q_LIKELY (form<d._msgstrPlural.size()))
         return d._msgstrPlural.at(form);
     else
         return d._msgstrPlural.last();
@@ -251,7 +251,7 @@ QStringList CatalogItem::msgstrAsList() const
 {
     if (d._msgstrPlural.isEmpty())
     {
-        qWarning()<<"This should never happen!";
+        qCWarning(LOKALIZE_LOG)<<"This should never happen!";
         return QStringList();
     }
     QStringList list(d._msgstrPlural.first().split('\n', QString::SkipEmptyParts ));
