@@ -22,6 +22,9 @@
 **************************************************************************** */
 
 #include "editortab.h"
+
+#include "lokalize_debug.h"
+
 #include "actionproxy.h"
 #include "editorview.h"
 #include "catalog.h"
@@ -53,11 +56,9 @@
 #include "project.h"
 #include "prefs.h"
 #include "languagelistmodel.h"
-#include "kdemacros.h"
 
 #ifndef NOKDE
 #include <ktoolbarpopupaction.h>
-#include <kdemacros.h>
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kstandardshortcut.h>
@@ -68,7 +69,6 @@
 #include <kmessagebox.h>
 #include <klocalizedstring.h>
 
-#include <QDebug>
 #include <QDesktopServices>
 #include <QIcon>
 #include <QActionGroup>
@@ -136,7 +136,7 @@ EditorTab::EditorTab(QWidget* parent, bool valid)
 
     //defer some work to make window appear earlier (~200 msec on my Core Duo)
     //QTimer::singleShot(0,this,SLOT(initLater()));
-    //qWarning()<<chrono.elapsed();
+    //qCWarning(LOKALIZE_LOG)<<chrono.elapsed();
 }
 
 void EditorTab::initLater()
@@ -528,7 +528,7 @@ void EditorTab::setupActions()
 
 #ifndef Q_OS_DARWIN
     int copyShortcut=Qt::CTRL+Qt::Key_Space;
-    if (KDE_ISUNLIKELY( systemLang==QLocale::Korean
+    if (Q_UNLIKELY( systemLang==QLocale::Korean
                      || systemLang==QLocale::Japanese
                      || systemLang==QLocale::Chinese
                     ))
@@ -1107,7 +1107,7 @@ void EditorTab::gotoEntry(DocPosition pos, int selection)
     }
 
     statusBarItems.insert(ID_STATUS_CURRENT,i18nc("@info:status","Current: %1", m_currentPos.entry+1));
-    //qDebug()<<"ELA "<<time.elapsed();
+    //qCDebug(LOKALIZE_LOG)<<"ELA "<<time.elapsed();
 }
 
 void EditorTab::msgStrChanged()
@@ -1614,7 +1614,7 @@ void EditorTab::mergeIntoOpenDocument()
     args.append(xliffFolder%'/'%originalOdfFileInfo.baseName()%'-'%targetLangCode%'.'%originalOdfFileInfo.suffix());
     args.append(QStringLiteral("-t"));
     args.append(originalOdfFilePath);
-    qDebug()<<args;
+    qCDebug(LOKALIZE_LOG)<<args;
     QProcess::execute(xliff2odf, args);
 
     if (!QFile::exists(args.at(1)))
